==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/DataGridExpansionIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridExpansionIndicatorDescription } from "./DataGridExpansionIndicatorDescription";
/**
 * @hidden
 */
export let DataGridExpansionIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataGridExpansionIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (DataGridExpansionIndicatorDescriptionMetadata.a == null) {
                DataGridExpansionIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataGridExpansionIndicatorDescriptionMetadata.c(DataGridExpansionIndicatorDescriptionMetadata.a);
            }
            if (a.j(DataGridExpansionIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.y(DataGridExpansionIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            a.item("IsExpanded", "Boolean");
            a.item("IconColor", "Brush");
            a.item("IsAnimationEnabled", "Boolean");
            a.item("PixelScalingRatio", "Number:double");
            a.item("ActualPixelScalingRatio", "Number:double");
        }
        static d(a) {
            DataGridExpansionIndicatorDescriptionMetadata.b(a);
            a.aa("DataGridExpansionIndicator", () => new DataGridExpansionIndicatorDescription());
            a.z("DataGridExpansionIndicator", DataGridExpansionIndicatorDescriptionMetadata.a);
        }
    }
    DataGridExpansionIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(DataGridExpansionIndicatorDescriptionMetadata, 'DataGridExpansionIndicatorDescriptionMetadata');
    DataGridExpansionIndicatorDescriptionMetadata.a = null;
    return DataGridExpansionIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/DataGridExpansionIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridExpansionIndicatorDescription } from "./DataGridExpansionIndicatorDescription";
/**
 * @hidden
 */
export let DataGridExpansionIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataGridExpansionIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (DataGridExpansionIndicatorDescriptionMetadata.a == null) {
                DataGridExpansionIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataGridExpansionIndicatorDescriptionMetadata.c(DataGridExpansionIndicatorDescriptionMetadata.a);
            }
            if (a.k(DataGridExpansionIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(DataGridExpansionIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            a.item("IsExpanded", "Boolean");
            a.item("IconColor", "Brush");
            a.item("IsAnimationEnabled", "Boolean");
            a.item("PixelScalingRatio", "Number:double");
            a.item("ActualPixelScalingRatio", "Number:double");
        }
        static d(a) {
            DataGridExpansionIndicatorDescriptionMetadata.b(a);
            a.ac("DataGridExpansionIndicator", () => new DataGridExpansionIndicatorDescription());
            a.ab("DataGridExpansionIndicator", DataGridExpansionIndicatorDescriptionMetadata.a);
        }
    }
    DataGridExpansionIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(DataGridExpansionIndicatorDescriptionMetadata, 'DataGridExpansionIndicatorDescriptionMetadata');
    DataGridExpansionIndicatorDescriptionMetadata.a = null;
    return DataGridExpansionIndicatorDescriptionMetadata;
})();
